Method: Hash#rmerge

Defined in:
lib/tml/ext/hash.rb

#rmerge(other_hash) ⇒ Object

Recursive version of Hash#merge

Compared with Hash#merge!, this method supports nested hashes. When both hsh and other_hash contains an entry with the same key, it merges and returns the values from both arrays.

Compared with Hash#merge, this method provides a different approch for merging nasted hashes. If the value of a given key is an Hash and both other_hash abd +hsh includes the same key, the value is merged instead replaced with other_hash value.

h1 = {"a" => 100, "b" => 200, "c" => {"c1" => 12, "c2" => 14}}
h2 = {"b" => 254, "c" => 300, "c" => {"c1" => 16, "c3" => 94}}
h1.rmerge(h2)    #=> {"a" => 100, "b" => 254, "c" => {"c1" => 16, "c2" => 14, "c3" => 94}}

Simply using Hash#merge would return

h1.merge(h2)     #=> {"a" => 100, "b" = >254, "c" => {"c1" => 16, "c3" => 94}}


92
93
94
95
96
97
# File 'lib/tml/ext/hash.rb', line 92

def rmerge(other_hash)
  r = {}
  merge(other_hash)  do |key, oldval, newval| 
    r[key] = oldval.class == self.class ? oldval.rmerge(newval) : newval
  end
end